"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const regexMatcher_1 = require("../lib/regexMatcher");
const chai_1 = require("chai");
const jsonata = require("jsonata");
exports.awsSdkStepRunners = ({ region, }) => [
    {
        willRun: regexMatcher_1.regexMatcher(/^I execute "([^"]+)" of the AWS ([^ ]+) SDK with$/),
        run: async ([method, api], step, runner) => {
            if (!step.interpolatedArgument) {
                throw new Error('Must provide argument!');
            }
            const argument = JSON.parse(step.interpolatedArgument);
            await runner.progress('AWS-SDK', `${api}.${method}(${JSON.stringify(argument)})`);
            const a = new AWS[api]({
                region,
            });
            const res = await a[method](argument).promise();
            runner.store.awsSdk = {
                res,
            };
            return res;
        },
    },
    {
        willRun: regexMatcher_1.regexMatcher(/^(?:"([^"]+)" of )?the execution result should (equal|match) this JSON$/),
        run: async ([exp, equalOrMatch], step, runner) => {
            const { awsSdk } = runner.store;
            if (!step.interpolatedArgument) {
                throw new Error('Must provide argument!');
            }
            const j = JSON.parse(step.interpolatedArgument);
            const result = awsSdk.res;
            const fragment = exp ? jsonata(exp).evaluate(result) : result;
            if (equalOrMatch === 'match') {
                chai_1.expect(fragment).to.containSubset(j);
            }
            else {
                chai_1.expect(fragment).to.deep.equal(j);
            }
            return [fragment];
        },
    },
];
